pub enum CombatEffect {
Show 13 variants
Heal(f32),
Buff(CombatBuff),
Knockback(Knockback),
EnergyReward(f32),
Lifesteal(f32),
Poise(f32),
Combo(i32),
AdditionalDamage(f32),
RefreshBuff(f32, BuffKind),
SelfBuff(CombatBuff),
Energy(f32),
Transform {
entity_spec: String,
allow_players: bool,
},
DebuffsVulnerable {
mult: f32,
scaling: ScalingKind,
filter_attacker: bool,
filter_weapon: Option<ToolKind>,
},
}Variants
Heal(f32)
Buff(CombatBuff)
Knockback(Knockback)
EnergyReward(f32)
Lifesteal(f32)
Poise(f32)
Combo(i32)
AdditionalDamage(f32)
Intended to be used when gating additional damage behind some requirement
RefreshBuff(f32, BuffKind)
Resets duration of all buffs of this buffkind, with some probability
SelfBuff(CombatBuff)
Applies buff to yourself after attack is applied
Energy(f32)
Changes energy of target
Transform
String is the entity_spec
DebuffsVulnerable
If the target hit by an attack has debuffs, they will take increased damage scaling with the number of active debuffs they have
Implementations
Sourceimpl CombatEffect
impl CombatEffect
pub fn apply_multiplier(self, mult: f32) -> Self
pub fn adjusted_by_stats(self, stats: Stats) -> Self