pub struct RiderEffects(pub Vec<BuffEffect>);Expand description
Effects applied to the rider of this entity while riding.
Tuple Fields
0: Vec<BuffEffect>Trait Implementations
Sourceimpl Clone for RiderEffects
impl Clone for RiderEffects
Sourcefn clone(&self) -> RiderEffects
fn clone(&self) -> RiderEffects
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Component for RiderEffects
impl Component for RiderEffects
Sourcetype Storage = DenseVecStorage<RiderEffects>
type Storage = DenseVecStorage<RiderEffects>
Associated storage type for this component.
Sourceimpl Debug for RiderEffects
impl Debug for RiderEffects
Sourceimpl PartialEq for RiderEffects
impl PartialEq for RiderEffects
Sourcefn eq(&self, other: &RiderEffects) -> bool
fn eq(&self, other: &RiderEffects) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RiderEffects