pub enum CombatEffect {
Show 15 variants
Heal(f32),
Buff(CombatBuff),
Knockback(Knockback),
EnergyReward(f32),
Lifesteal(f32),
Poise(f32),
Combo(i32),
StageVulnerable(f32, StageSection),
RefreshBuff(f32, BuffKind),
BuffsVulnerable(f32, BuffKind),
StunnedVulnerable(f32),
SelfBuff(CombatBuff),
Energy(f32),
Transform {
entity_spec: String,
allow_players: bool,
},
DebuffsVulnerable {
mult: f32,
scaling: ScalingKind,
filter_attacker: bool,
filter_weapon: Option<ToolKind>,
},
}Variants
Heal(f32)
Buff(CombatBuff)
Knockback(Knockback)
EnergyReward(f32)
Lifesteal(f32)
Poise(f32)
Combo(i32)
StageVulnerable(f32, StageSection)
If the attack hits the target while they are in the buildup portion of a character state, deal increased damage Only has an effect when attached to a damage, otherwise does nothing if only attached to the attack
RefreshBuff(f32, BuffKind)
Resets duration of all buffs of this buffkind, with some probability
BuffsVulnerable(f32, BuffKind)
If the target hit by an attack has this buff, they will take increased damage. Only has an effect when attached to a damage, otherwise does nothing if only attached to the attack
StunnedVulnerable(f32)
If the target hit by an attack is in a stunned state, they will take increased damage. Only has an effect when attached to a damage, otherwise does nothing if only attached to the attack
SelfBuff(CombatBuff)
Applies buff to yourself after attack is applied
Energy(f32)
Changes energy of target
Transform
String is the entity_spec
DebuffsVulnerable
If the target hit by an attack has debuffs, they will take increased damage scaling with the number of active debuffs they have
Implementations
Sourceimpl CombatEffect
impl CombatEffect
pub fn apply_multiplier(self, mult: f32) -> Self
pub fn adjusted_by_stats(self, stats: Stats) -> Self